**WORK IN PROGRESS**

# Network Automation Tools Integrator

This package conains the core `nauti` libraries.  Future repositories will be become
available to support various systems and tools that are used for network automation workflows.

Stay tuned for more.
